@@ -1,5 +1,6 @@
 (ns schema.utils
   "Private utilities used in schema implementation."
+  (:refer-clojure :exclude [record?])
                                                                 )
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -19,6 +20,13 @@
         (class x)
                              )
 
+(defn fn-schema-bearer
+  "What class can we associate the fn schema with? In Clojure use the class of the fn; in
+   cljs just use the fn itself."
+  [f]
+        (class f)
+          )
+
 (defn format* [fmt & args]
   (apply       format                       fmt args))
 
@@ -30,6 +38,23 @@
       value
       (symbol (str "a-"       (.getName ^Class t)         )))))
 
+(defn memoize-id
+  "Identity version of memoize, because many schemas are records, and records
+   don't cache their hash codes (at least in Clojure 1.5.1).
+   Not thread safe, and doesn't cache falsey values."
+  [f]
+        (let [m (java.util.IdentityHashMap.)]
+          (fn [x]
+            (or (.get m x)
+                (let [res (f x)]
+                  (.put m x res)
+                  res))))
+                    )
+
+(defn record? [x]
+        (instance? clojure.lang.IRecord x)
+                               )
+
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;; Error descriptions
@@ -166,7 +191,7 @@
 
 (def ^schema.utils.PSimpleCell use-fn-validation
   "Turn on run-time function validation for functions compiled when
-   *compile-function-validation* was true -- has no effect for functions compiled
+   s/compile-fn-validation was true -- has no effect for functions compiled
    when it is false."
   (SimpleVCell. false))
 
@@ -175,4 +200,4 @@
                                                                             
                                                                              
 
-;;;;;;;;;;;; This file autogenerated from /Users/w01fe/prismatic/open-source/schema/src/cljx/schema/utils.cljx
+;;;;;;;;;;;; This file autogenerated from src/cljx/schema/utils.cljx
